=========================
Recursive Neural Networks
=========================

Papers
======

* [15.03] `Improved Semantic Representations From Tree-Structured Long Short-Term Memory Networks <https://arxiv.org/abs/1503.00075>`_
* [16.03] `A Fast Unified Model for Parsing and Sentence Understanding <https://arxiv.org/abs/1603.06021>`_


Codes
=====

* `Improved Semantic Representations From Tree-Structured Long Short-Term Memory Networks <https://github.com/ofirnachum/tree_rnn>`_, theano implementation
* `A Fast Unified Model for Parsing and Sentence Understanding <https://github.com/stanfordnlp/spinn>`_, theano implementation
* `MultiPath/Dep-Compo <https://github.com/MultiPath/Dep-Compo>`_, theano implementation

Blogs
=====

* `Hybrid tree-sequence neural networks with SPINN <http://nlp.stanford.edu/blog/hybrid-tree-sequence-neural-networks-with-spinn>`_
